@@ -4,7 +4,7 @@ from django.apps import AppConfig
 
 
 class AgendaConfig(AppConfig):
-    name = 'pretalx.agenda'
+    name = "pretalx.agenda"
 
     def ready(self):
         from . import permissions  # noqa
@@ -12,6 +12,6 @@ class AgendaConfig(AppConfig):
 
 
 with suppress(ImportError):
-    import pretalx.celery_app as celery  # NOQA
+    from pretalx import celery_app as celery  # noqa
 
-default_app_config = 'pretalx.agenda.AgendaConfig'
+default_app_config = "pretalx.agenda.AgendaConfig"
