@@ -2,7 +2,7 @@ from django.apps import AppConfig
 
 
 class APIConfig(AppConfig):
-    name = 'pretalx.api'
+    name = "pretalx.api"
 
 
-default_app_config = 'pretalx.api.APIConfig'
+default_app_config = "pretalx.api.APIConfig"
