@@ -2,11 +2,11 @@ from django.apps import AppConfig
 
 
 class CfPConfig(AppConfig):
-    name = 'pretalx.cfp'
+    name = "pretalx.cfp"
 
     def ready(self):
         from . import permissions  # noqa
         from .phrases import CfPPhrases  # noqa
 
 
-default_app_config = 'pretalx.cfp.CfPConfig'
+default_app_config = "pretalx.cfp.CfPConfig"
