@@ -1,7 +1,4 @@
 from .log import ActivityLog
 from .settings import GlobalSettings
 
-__all__ = [
-    'ActivityLog',
-    'GlobalSettings'
-]
+__all__ = ["ActivityLog", "GlobalSettings"]
