@@ -3,9 +3,4 @@ from .room import Room
 from .schedule import Schedule
 from .slot import TalkSlot
 
-__all__ = [
-    'Availability',
-    'Room',
-    'Schedule',
-    'TalkSlot',
-]
+__all__ = ["Availability", "Room", "Schedule", "TalkSlot"]
