@@ -1,10 +1,6 @@
-"""
-WSGI config for pretalx project.
+"""WSGI config for pretalx.
 
-It exposes the WSGI callable as a module-level variable named ``application``.
-
-For more information on this file, see
-https://docs.djangoproject.com/en/dev/howto/deployment/wsgi/
+Use with gunicorn or uwsgi.
 """
 
 import os
@@ -15,6 +11,7 @@ from django.core.wsgi import get_wsgi_application  # NOQA
 
 try:
     from dj_static import Cling, MediaCling
+
     application = Cling(MediaCling(get_wsgi_application()))
 except ImportError:
     application = get_wsgi_application()
